@@ -477,10 +477,13 @@ class ProjectionExtensionHooks(ExtensionHooks):
             return
 
         # proj:epsg moved to proj:code
-        if "proj:epsg" in obj["properties"]:
-            epsg = obj["properties"]["proj:epsg"]
+        if epsg := obj["properties"].pop("proj:epsg", None):
             obj["properties"]["proj:code"] = f"EPSG:{epsg}"
-            del obj["properties"]["proj:epsg"]
+
+        for key in ["assets", "item_assets"]:
+            for asset in obj.get(key, {}).values():
+                if epsg := asset.pop("proj:epsg", None):
+                    asset["proj:code"] = f"EPSG:{epsg}"
 
         super().migrate(obj, version, info)
 
