@@ -1,13 +1,16 @@
 from __future__ import annotations
 
+import os
 import posixpath
 import warnings
 from abc import ABC, abstractmethod
 from collections import OrderedDict
+from collections.abc import Callable
 from string import Formatter
-from typing import TYPE_CHECKING, Any, Callable
+from typing import TYPE_CHECKING, Any
 
 import pystac
+from pystac.utils import is_file_path
 
 if TYPE_CHECKING:
     from pystac.catalog import Catalog
@@ -258,6 +261,9 @@ class HrefLayoutStrategy(ABC):
     def get_href(
         self, stac_object: STACObject, parent_dir: str, is_root: bool = False
     ) -> str:
+        if is_file_path(parent_dir):
+            parent_dir = os.path.dirname(parent_dir)
+
         if isinstance(stac_object, pystac.Item):
             return self.get_item_href(stac_object, parent_dir)
         elif isinstance(stac_object, pystac.Collection):
@@ -529,3 +535,162 @@ class AsIsLayoutStrategy(HrefLayoutStrategy):
             )
         else:
             return href
+
+
+class APILayoutStrategy(HrefLayoutStrategy):
+    """Layout strategy that represents the STAC API endpoint layout described
+    in the `STAC API Specifications
+    <https://github.com/radiantearth/stac-api-spec/blob/v1.0.0/overview.md#endpoints>`_
+
+    The URL of the root catalog will be the base URL of the API.
+    Other catalogs will be listed underneath their parent catalog
+    at ``./${id}``.
+    Collections will be found underneath the root or their parent
+    catalog at ``./collections/${id}``. Collection cannot be the root themselves.
+    Items will be found underneath their collections at
+    ``./collections/${collection}/items/${id}``.
+    """
+
+    def get_catalog_href(
+        self, cat: Catalog | str, parent_dir: str, is_root: bool
+    ) -> str:
+        """
+        Generate a catalog href based on the provided parameters.
+
+        Parameters:
+        cat (Catalog | str): The catalog object or its ID.
+        parent_dir (str): The parent directory for the catalog.
+        is_root (bool): A flag indicating whether the catalog is a root catalog.
+
+        Returns:
+        str: The generated catalog href.
+        """
+
+        if not isinstance(cat, str):
+            cat = cat.id
+
+        if is_root:
+            cat_href = parent_dir
+        else:
+            cat_href = posixpath.join(parent_dir, cat)
+
+        return cat_href
+
+    def get_collections_href(self, parent_dir: str) -> str:
+        """
+        Generate a collections href based on the provided parent directory.
+
+        Parameters:
+        parent_dir (str): The parent directory for the collections.
+
+        Returns:
+        str: The generated collections href.
+        """
+        return posixpath.join(parent_dir, "collections")
+
+    def get_collection_href(
+        self, col: Collection | str, parent_dir: str, is_root: bool
+    ) -> str:
+        """
+        Generate a collection href based on the provided parameters.
+
+        Parameters:
+        col (Collection | str): The collection object or its ID.
+        parent_dir (str): The parent directory for the collection.
+        is_root (bool): A flag indicating whether the collection is a root collection.
+
+        Returns:
+        str: The generated collection href.
+
+        Raises:
+        ValueError: If the collection is set as root.
+        """
+
+        if not isinstance(col, str):
+            col = col.id
+
+        if is_root:
+            raise ValueError("Collections cannot be root")
+
+        col_root = self.get_collections_href(parent_dir)
+
+        return posixpath.join(col_root, col)
+
+    def get_items_href(self, parent_dir: str) -> str:
+        """
+        Generate an items href based on the provided parent directory.
+
+        Parameters:
+        parent_dir (str): The parent directory for the items.
+
+        Returns:
+        str: The generated items href.
+        """
+        return posixpath.join(parent_dir, "items")
+
+    def get_item_href(self, item: Item | str, parent_dir: str) -> str:
+        """
+        Generate an item href based on the provided parameters.
+
+        Parameters:
+        item (Item | str): The item object or its ID.
+        parent_dir (str): The parent directory for the item.
+
+        Returns:
+        str: The generated item href.
+        """
+        if not isinstance(item, str):
+            item = item.id
+
+        item_root = self.get_items_href(parent_dir)
+
+        return posixpath.join(item_root, item)
+
+    def get_search_href(self, parent_dir: str) -> str:
+        """
+        Generate a search href based on the provided parent directory.
+
+        Parameters:
+        parent_dir (str): The parent directory for the search.
+
+        Returns:
+        str: The generated search href.
+        """
+        return posixpath.join(parent_dir, "search")
+
+    def get_conformance_href(self, parent_dir: str) -> str:
+        """
+        Generate a conformance href based on the provided parent directory.
+
+        Parameters:
+        parent_dir (str): The parent directory for the conformance.
+
+        Returns:
+        str: The generated conformance href.
+        """
+        return posixpath.join(parent_dir, "conformance")
+
+    def get_service_desc_href(self, parent_dir: str) -> str:
+        """
+        Generate an API service description href based on the provided parent directory.
+
+        Parameters:
+        parent_dir (str): The parent directory for the API.
+
+        Returns:
+        str: The generated API href.
+        """
+        return posixpath.join(parent_dir, "api")
+
+    def get_service_doc_href(self, parent_dir: str) -> str:
+        """
+        Generate an API service documentation href based on
+        the provided parent directory.
+
+        Parameters:
+        parent_dir (str): The parent directory for the API.
+
+        Returns:
+        str: The generated API href.
+        """
+        return posixpath.join(parent_dir, "api.html")
