@@ -24,3 +24,7 @@ class MediaType(StringEnum):
     PDF = "application/pdf"
     ZARR = "application/vnd+zarr"  # https://github.com/openMetadataInitiative/openMINDS_core/blob/v4/instances/data/contentTypes/zarr.jsonld
     NETCDF = "application/netcdf"  # https://github.com/Unidata/netcdf/issues/42#issuecomment-1007618822
+
+
+#: Media types that can be resolved as STAC Objects
+STAC_JSON = [None, MediaType.GEOJSON, MediaType.JSON]
