@@ -16,7 +16,7 @@ from pystac.serialization import (
     merge_common_properties,
     migrate_to_latest,
 )
-from pystac.utils import HREF, safe_urlparse
+from pystac.utils import HREF, _is_url, safe_urlparse
 
 # Use orjson if available
 try:
@@ -169,19 +169,19 @@ class StacIO(ABC):
 
         if info.object_type == pystac.STACObjectType.CATALOG:
             result = pystac.Catalog.from_dict(
-                d, href=href_str, root=root, migrate=False, preserve_dict=preserve_dict
+                d, href=href_str, root=root, migrate=True, preserve_dict=preserve_dict
             )
             result._stac_io = self
             return result
 
         if info.object_type == pystac.STACObjectType.COLLECTION:
             return pystac.Collection.from_dict(
-                d, href=href_str, root=root, migrate=False, preserve_dict=preserve_dict
+                d, href=href_str, root=root, migrate=True, preserve_dict=preserve_dict
             )
 
         if info.object_type == pystac.STACObjectType.ITEM:
             return pystac.Item.from_dict(
-                d, href=href_str, root=root, migrate=False, preserve_dict=preserve_dict
+                d, href=href_str, root=root, migrate=True, preserve_dict=preserve_dict
             )
 
         raise ValueError(f"Unknown STAC object type {info.object_type}")
@@ -303,6 +303,7 @@ class DefaultStacIO(StacIO):
             except HTTPError as e:
                 raise Exception(f"Could not read uri {href}") from e
         else:
+            href = safe_urlparse(href).path
             with open(href, encoding="utf-8") as f:
                 href_contents = f.read()
         return href_contents
@@ -310,7 +311,8 @@ class DefaultStacIO(StacIO):
     def write_text(self, dest: HREF, txt: str, *_: Any, **__: Any) -> None:
         """A concrete implementation of :meth:`StacIO.write_text
         <pystac.StacIO.write_text>`. Converts the ``dest`` argument to a string (if it
-        is not already) and delegates to :meth:`DefaultStacIO.write_text_from_href` for
+        is not already) and delegates to
+        W:meth:`~pystac.stac_io.DefaultStacIO.write_text_to_href` for
         opening and reading the file."""
         href = str(os.fspath(dest))
         return self.write_text_to_href(href, txt)
@@ -328,7 +330,7 @@ class DefaultStacIO(StacIO):
         """
         if _is_url(href):
             raise NotImplementedError("DefaultStacIO cannot write to urls")
-        href = os.fspath(href)
+        href = safe_urlparse(href).path
         dirname = os.path.dirname(href)
         if dirname != "" and not os.path.isdir(dirname):
             os.makedirs(dirname)
@@ -389,11 +391,6 @@ class DuplicateKeyReportingMixin(StacIO):
         return result
 
 
-def _is_url(href: str) -> bool:
-    parsed = safe_urlparse(href)
-    return parsed.scheme != ""
-
-
 if HAS_URLLIB3:
     from typing import cast
 
