@@ -4,6 +4,7 @@ __all__ = [
     "ARBITRARY_BBOX",
     "ARBITRARY_EXTENT",
     "MockStacIO",
+    "path_includes_drive_letter",
 ]
 from copy import deepcopy
 from datetime import datetime
@@ -12,6 +13,7 @@ from typing import Any
 from dateutil.parser import parse
 
 import pystac
+from tests.utils.os_utils import path_includes_drive_letter
 from tests.utils.stac_io_mock import MockStacIO
 from tests.utils.test_cases import (
     ARBITRARY_BBOX,
@@ -40,7 +42,7 @@ def assert_to_from_dict(
                         a_dict[k] = a_dict[k].replace(microsecond=0)
 
     d1 = deepcopy(d)
-    d2 = stac_object_class.from_dict(d).to_dict()
+    d2 = stac_object_class.from_dict(d, migrate=False).to_dict()
     _parse_times(d1)
     _parse_times(d2)
     assert d1 == d2
